==> InTAD_1.0.0.tar.gz: InTAD/R/example_data_info.R <==
#' @name enhSel
#' @title Enhancer signals subset detected from medulloblatoma samples
#' @description This data.frame contains 65 selected in chr15  normalized
#' enhancers signals subset from 25 medulloblastoma samples.
#' @return NULL, but makes available the dataframe
#' @docType data
#' @usage enhSel
#' @format a data.frame instance
NULL

#' @name enhSelGR
#' @title Genomic coordiantes of enhancer signals subet
#' @description This GRanges object contains the coordinates of 65
#' medulloblastoma enhancer signals in chr15 target region
#' @return NULL, but makes available the dataset
#' @docType data
#' @usage enhSelGR
#' @format a GRanges object
NULL

#' @name rpkmCountsSel
#' @title Gene expression subset from medulloblastoma samples
#' @description This data.frame contains RPKM gene expression values from chr15
#' for subset from 25 medulluoblastoma samples.
#' @return NULL, but makes available the dataframe
#' @docType data
#' @usage rpkmCountsSel
#' @format a data.frame instance
NULL

#' @name txsSel
#' @title Genomic coordiantes of genes subset
#' @description This GRanges object contains the coordinates of genes
#' subset from chr15
#' @return NULL, but makes avaialbe the dataset
#' @docType data
#' @usage txsSel
#' @format a GRanges object
NULL

#' @name tadGR
#' @title Genomic coordiantes of topologically associated domains
#' @description This GRanges object contains the coordinates of TADs
#' revealed from IMR90 cell line
#' @return NULL, but makes available the dataset
#' @docType data
#' @usage tadGR
#' @format a GRanges object
NULL

#' @name mbAnnData
#' @title Data frame containing information about sampless
#' @description The table includes additional informaiton about MB tumour
#' samples (subgroup, gender, age, histology and M.Stage)
#' @return NULL, but makes available the dataset
#' @docType data
#' @usage mbAnnData
#' @format a data.frame object
NULL

==> InTAD_1.2.2.tar.gz: InTAD/R/example_data_info.R <==
#' @name enhSel
#' @title Enhancer signals subset detected from medulloblatoma samples
#' @description This data.frame contains 65 selected in chr15  normalized
#' enhancers signals subset from 25 medulloblastoma samples.
#' @return NULL, but makes available the dataframe
#' @docType data
#' @usage enhSel
#' @format a data.frame instance
NULL

#' @name enhSelGR
#' @title Genomic coordiantes of enhancer signals subet
#' @description This GRanges object contains the coordinates of 65
#' medulloblastoma enhancer signals in chr15 target region
#' @return NULL, but makes available the dataset
#' @docType data
#' @usage enhSelGR
#' @format a GRanges object
NULL

#' @name rpkmCountsSel
#' @title Gene expression subset from medulloblastoma samples
#' @description This data.frame contains RPKM gene expression values from chr15
#' for subset from 25 medulluoblastoma samples.
#' @return NULL, but makes available the dataframe
#' @docType data
#' @usage rpkmCountsSel
#' @format a data.frame instance
NULL

#' @name txsSel
#' @title Genomic coordiantes of genes subset
#' @description This GRanges object contains the coordinates of genes
#' subset from chr15
#' @return NULL, but makes avaialbe the dataset
#' @docType data
#' @usage txsSel
#' @format a GRanges object
NULL

#' @name tadGR
#' @title Genomic coordiantes of topologically associated domains
#' @description This GRanges object contains the coordinates of TADs
#' revealed from IMR90 cell line (extracted from 0-indexed .bed file)
#' @return NULL, but makes available the dataset
#' @docType data
#' @usage tadGR
#' @format a GRanges object
NULL

#' @name mbAnnData
#' @title Data frame containing information about sampless
#' @description The table includes additional informaiton about MB tumour
#' samples (subgroup, gender, age, histology and M.Stage)
#' @return NULL, but makes available the dataset
#' @docType data
#' @usage mbAnnData
#' @format a data.frame object
NULL
